<?php
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    
    function thegoodplasticcompany_setup() {
        // Make theme available for translation
    	load_theme_textdomain( 'thegoodplasticcompany', get_template_directory() . '/languages' );
        
        // Add default posts and comments RSS feed links to head
        add_theme_support( 'automatic-feed-links' );
        
        /*
    	 * Let WordPress manage the document title.
    	 * Here we declare that this theme does not use a hard-coded <title> tag in the document head
    	 */
        add_theme_support( 'title-tag' );
        
        // Enable support for Post Thumbnails on posts and pages
        add_theme_support( 'post-thumbnails' );
        
        // Set post thumbnail size
        set_post_thumbnail_size( 640, 640, true );
        
        // Add custom thumbnail sizes
        add_image_size( 'portrait', 525, 640, true );
        add_image_size( 'landscape', 640, 525, true );
        
        // Register navigation menus
        register_nav_menus(
            array(
        		'main'      => __('Header menu', 'thegoodplasticcompany'),
                'primary'   => __('Primary popup menu', 'thegoodplasticcompany'),
                'secondary' => __('Secondary popup menu', 'thegoodplasticcompany'),
        		'footer'    => __('Footer menu', 'thegoodplasticcompany'),
        		'social'    => __('Social links', 'thegoodplasticcompany'),
        	)
        );
        
        // Switch default core markup to output valid HTML5
    	add_theme_support(
    		'html5',
    		array(
    			'search-form',
    			'comment-form',
    			'comment-list',
    			'gallery',
    			'caption',
    			'script',
    			'style',
    		)
    	);
        
        // Add theme support for selective refresh for widgets
        add_theme_support( 'customize-selective-refresh-widgets' );
        
        // Add support for responsive embed blocks
        add_theme_support( 'responsive-embeds' );
        
        // Set up the WordPress core custom logo feature
		add_theme_support( 'custom-logo', apply_filters( 'thegoodplasticcompany_custom_logo_args', array(
			'width'       => 256,
			'height'      => 233,
			'flex-height' => true,
			'flex-width'  => true
		) ) );    
        
        // Disable color and font settings for preset blocks
        add_theme_support( 'editor-font-sizes', array() );
        add_theme_support( 'editor-color-palette', array() );
        // Disabling custom gradients
        add_theme_support( 'disable-custom-gradients' );
        
        // Disabling custom colors
        add_theme_support( 'disable-custom-colors' );
        
        // Disabling custom font sizes
        add_theme_support( 'disable-custom-font-sizes' );
        
        // Editor styles
        add_theme_support('editor-styles');
    }
    add_action( 'after_setup_theme', 'thegoodplasticcompany_setup' );
    
    /**
     * REQUIRED FILES
     * Include required files.
     */
    // classes
    require get_template_directory() . '/inc/classes/custom-post-types.php';
    require get_template_directory() . '/inc/classes/tgmpa/tgmpa.php';
    
    // plugins
    require get_template_directory() . '/inc/plugins/acf/acf.php';
    
    // functions
    require get_template_directory() . '/inc/plugins-check.php';
    require get_template_directory() . '/inc/customizer.php';
    require get_template_directory() . '/inc/custom-blocks.php';
    require get_template_directory() . '/inc/custom-fields.php';
    require get_template_directory() . '/inc/post-types.php';
    
    // plugins_url for inc plugins
    function thegoodplasticcompany_filter_plugins_url( $url, $path, $plugin ) {
        if( preg_match('|' . preg_quote('themes/thegoodplasticcompany/inc', '|') . '|', $plugin) ) {
            $url = get_template_directory_uri() . '/inc/plugins/' . basename ( dirname ($plugin) ) . ( !empty($path) ? '/' . $path : '');
        }
        return $url; 
    };
    add_filter( 'plugins_url', 'thegoodplasticcompany_filter_plugins_url', 10, 3 );
    
    // assets
    function thegoodplasticcompany_localize_scripts() {
        // Register the script
        wp_register_script( 'main', get_stylesheet_directory_uri(). '/assets/scripts/main.js', array('jquery'), false, true );
     
        // Localize the script with new data
        $script_data_array = array(
            'ajaxurl' => admin_url( 'admin-ajax.php' ),
            'security' => wp_create_nonce( 'load_product' ),
        );
        wp_localize_script( 'main', 'products', $script_data_array );
    }
    add_action( 'wp_enqueue_scripts', 'thegoodplasticcompany_localize_scripts' );
    function thegoodplasticcompany_assets() {
		wp_enqueue_script( 'thegoodplasticcompany-libs', get_template_directory_uri() . '/assets/scripts/libs.js', array('jquery'), null, true );
		wp_enqueue_style( 'thegoodplasticcompany-styles', get_template_directory_uri() . '/assets/styles/main.css', array(), 'kb001769' );
		wp_enqueue_script( 'main', get_template_directory_uri() . '/assets/scripts/main.js', array('jquery'), 'kb001769', true );
}
add_action( 'wp_enqueue_scripts', 'thegoodplasticcompany_assets' );

    
    // product ajax
    function thegoodplasticcompany_product_ajax_callback() {
        check_ajax_referer('load_product', 'security');
        
        if(!empty($_POST['product'])) {
            global $post;
            $post = get_post($_POST['product']);
            setup_postdata( $post );
            get_template_part( 'template-parts/content-product-single' );
            wp_reset_postdata();
        }
        
        if(!empty($_POST['page'])) {
            $page_id = url_to_postid( $_POST['page'] );
            if($page_id) {
                global $post;
                $post = get_post($page_id);
                setup_postdata( $post );
                the_content();
                wp_reset_postdata();
            }
        }
     
        wp_die();
    }
    add_action('wp_ajax_load_product', 'thegoodplasticcompany_product_ajax_callback');
    add_action('wp_ajax_nopriv_load_product', 'thegoodplasticcompany_product_ajax_callback');
    
    /*
    function thegoodplasticcompany_editor_styles() {
        add_editor_style( 'assets/styles/editor/style-editor.css' );
    }
    add_action( 'admin_init', 'thegoodplasticcompany_editor_styles' );
    */
    function thegoodplasticcompany_editor_assets() {
        // Enqueue block editor JS
        wp_enqueue_script( '${textdomain}-editor-scripts-libs', get_template_directory_uri() . '/assets/scripts/editor/script-editor-libs.js', array('wp-blocks', 'wp-element', 'wp-editor'), '', true );

        // Enqueue block editor styles
        wp_enqueue_style( '${textdomain}-editor-styles', get_template_directory_uri() . '/assets/styles/editor/style-editor.css' );
    }
    add_action( 'enqueue_block_editor_assets', 'thegoodplasticcompany_editor_assets' );

    
    function thegoodplasticcompany_wp_admin_style() {
        wp_enqueue_style('thegoodplasticcompany_admin_css', get_template_directory_uri() . '/assets/styles/admin/admin.css');
    }
    add_action( 'admin_enqueue_scripts', 'thegoodplasticcompany_wp_admin_style' );
    
    /**
     * Set retina logo args
     */
    function thegoodplasticcompany_custom_logo_args($args) {
        // If the retina setting is active, double the recommended width and height
        if ( get_theme_mod( 'thegoodplasticcompany_retina_logo', false ) ) {
            $args['width']  = floor( $args['width'] * 2 );
            $args['height'] = floor( $args['height'] * 2 );
        }
        return $args;
    }
    add_filter ( 'thegoodplasticcompany_custom_logo_args', 'thegoodplasticcompany_custom_logo_args', 10, 1 );
    
    /**
     * Process custom logo html
     */
    function thegoodplasticcompany_custom_logo_html( $html ) {

    	$logo_id = get_theme_mod( 'custom_logo' );

    	if ( ! $logo_id ) {
    		return $html;
    	}

    	$logo = wp_get_attachment_image_src( $logo_id, 'full' );

    	if ( $logo ) {
            // Get attachment image width/height
    		$logo_width  = esc_attr( $logo[1] );
    		$logo_height = esc_attr( $logo[2] );

    		// If the retina logo setting is active, reduce the width/height by half
    		if ( get_theme_mod( 'thegoodplasticcompany_retina_logo', false ) ) {
    			$logo_width  = floor( $logo_width / 2 );
    			$logo_height = floor( $logo_height / 2 );

    			$search = array(
    				'/width=\"\d+\"/iU',
    				'/height=\"\d+\"/iU',
    			);

    			$replace = array(
    				"width=\"{$logo_width}\"",
    				"height=\"{$logo_height}\"",
    			);

    			// Add a style attribute with the height, or append the height to the style attribute if this attribute already exists
    			if ( strpos( $html, ' style=' ) === false ) {
    				$search[]  = '/(src=)/';
    				$replace[] = "style=\"height: {$logo_height}px;\" src=";
    			} else {
    				$search[]  = '/(style="[^"]*)/';
    				$replace[] = "$1 height: {$logo_height}px;";
    			}

    			$html = preg_replace( $search, $replace, $html );

    		}
    	}

    	return $html;

    }

    add_filter( 'get_custom_logo', 'thegoodplasticcompany_custom_logo_html' );
    
    /**
     * Adding to the Body Class
     *
     * @param array $classes
     */
    function thegoodplasticcompany_body_class( $classes ) {
        $classes[] = 'parallax-enabled';
        if ( is_page() ) {
            global $post;
            if( get_post_meta($post->ID, 'video_file', true) ) {
                $classes[] = 'header-absolute';
                if( get_post_meta($post->ID, 'video_style', true) == 'dark' ) {
                    $classes[] = 'header-inverted';
                }
            }
        }
        return $classes;
    }
    add_filter( 'body_class','thegoodplasticcompany_body_class' );
    
    /**
     * Displays the site logo
     *
     * @param boolean $is_dark_bg For dark or light background.
     * @param boolean $echo Echo or return the HTML.
     *
     * @return string $html Compiled HTML.
     */
    function thegoodplasticcompany_site_logo( $is_dark_bg = false, $echo = true ) {
        $alt_logo   = $is_dark_bg ? get_theme_mod('thegoodplasticcompany_alternative_logo') : 0;
    	$logo       = !empty($alt_logo) ? '<a href="' . home_url() . '">' . wp_get_attachment_image($alt_logo, 'full') . '</a>' : get_custom_logo();
    	$site_title = get_bloginfo( 'name' );
    	$contents   = '';
    	$classname  = '';

    	$args = array(
    		'logo'        => '%1$s<span class="screen-reader-text">%2$s</span>',
    		'logo_class'  => 'site-logo',
    		'title'       => '<a href="%1$s">%2$s</a>',
    		'title_class' => 'site-title',
    		'wrapper'     => '<div class="h5 %1$s">%2$s</div>'
    	);
        
        if ( has_custom_logo() ) {
    		$contents  = sprintf( $args['logo'], $logo, esc_html( $site_title ) );
    		$classname = $args['logo_class'];
    	} else {
    		$contents  = sprintf( $args['title'], esc_url( get_home_url( null, '/' ) ), esc_html( $site_title ) );
    		$classname = $args['title_class'];
    	}

    	$html = sprintf( $args[ 'wrapper' ], $classname, $contents );

    	if ( ! $echo ) {
    		return $html;
    	}
        
        echo $html;

    }
    
    /**
     * Inject social icons
     */
    function thegoodplasticcompany_menu_description( $item_output, $item, $depth, $args ) {
        if ( $args->theme_location == 'social' ) {
            $item_output = strtolower(preg_replace('/(?<=>).*?(facebook|linkedin|twitter|instagram|mail).*?(?=<\/a>)/i', '<i class="icon icon-$1"></i>', $item_output));
        }
      
        return $item_output;
    }
    add_filter( 'walker_nav_menu_start_el', 'thegoodplasticcompany_menu_description', 10, 4 );
    
    /**
     * Posts -> News
     */
    function thegoodplasticcompany_default_post_type_change($post_type, $post_type_object) {
        if($post_type == 'post') {
            $post_type_object->labels->name                 = __('News', 'thegoodplasticcompany');
            $post_type_object->labels->singular_name        = __('Post', 'thegoodplasticcompany');
            $post_type_object->labels->name_admin_bar       = __('Post', 'thegoodplasticcompany');
            $post_type_object->labels->menu_name            = __('News', 'thegoodplasticcompany');
            $post_type_object->menu_position                = 9;
        }
    }
    add_action( 'registered_post_type', 'thegoodplasticcompany_default_post_type_change', 10, 2 );
    
    /**
     * Archive title 
     */
    add_filter( 'get_the_archive_title', function ($title) {    
        if ( is_category() ) {    
                $title = single_cat_title( '', false );    
            } elseif ( is_tag() ) {    
                $title = single_tag_title( '', false );    
            } elseif ( is_author() ) {    
                $title = '<span class="vcard">' . get_the_author() . '</span>' ;    
            } elseif ( is_tax() ) { //for custom post types
                $title = sprintf( __( '%1$s' ), single_term_title( '', false ) );
            } elseif (is_post_type_archive()) {
                $title = post_type_archive_title( '', false );
            }
        return $title;    
    });
    
    /**
     * Inject projects to News query
     */
    function thegoodplasticcompany_projects_in_news_query($query) {
        if( !is_admin() && $query->is_main_query() && is_home() && !is_front_page() ) {
            $query->set('post_type', array('post','project'));
            
            global $wpdb;
            
            $exclude_posts = $wpdb->get_results(
                $wpdb->prepare(
                    "
                        SELECT post.ID
                        FROM {$wpdb->posts} AS post
                        WHERE post.post_type = '%s'
                        AND TRIM(IFNULL(post.post_content,'')) = ''
                    ", 'project'
                ), ARRAY_A
            );
            if ( !empty($exclude_posts) ) {
                $query->set('post__not_in', array_map('current',$exclude_posts));
            }
            
            /*
            $post_types = $query->get('post_type');             // Get the currnet post types in the query

            if(!is_array($post_types) && !empty($post_types))   // Check that the current posts types are stored as an array
                $post_types = explode(',', $post_types);

            if(empty($post_types))                              // If there are no post types defined, be sure to include posts so that they are not ignored
                $post_types[] = 'post';         
            $post_types[] = 'project';                         // Add your custom post type

            $post_types = array_map('trim', $post_types);       // Trim every element, just in case
            $post_types = array_filter($post_types);            // Remove any empty elements, just in case

            $query->set('post_type', $post_types);              // Add the updated list of post types to your query
            */
        }

        return $query;

    }
    add_action('pre_get_posts', 'thegoodplasticcompany_projects_in_news_query', 99);
    
    /**
     * Add custom image sizes
     */
    function thegoodplasticcompany_image_size_names( $sizes ) {
        $sizes['portrait'] = __('Portrait (Cropped)', 'thegoodplasticcompany');
        $sizes['landscape'] = __('Landscape (Cropped)', 'thegoodplasticcompany');
        $sizes['post-thumbnail'] = __('Square (Cropped)', 'thegoodplasticcompany');
        return $sizes;
    }
    add_filter( 'image_size_names_choose', 'thegoodplasticcompany_image_size_names', 11, 1 );
    
    /**
     * Filter adjacent post
     */
    function thegoodplasticcompany_adjacent_post_filter( $where ) {
        return $where . ' AND TRIM(IFNULL(p.post_content,"")) <> ""';
    }
    add_filter( 'get_previous_post_where', 'thegoodplasticcompany_adjacent_post_filter' );
    add_filter( 'get_next_post_where', 'thegoodplasticcompany_adjacent_post_filter' );
    
    /**
     * WP head injections
     */
    function thegoodplasticcompany_wp_head() {
        global $wp;
        $s_name        = get_bloginfo('name');
        $s_desc        = get_bloginfo('description');
        $default_thumb = get_theme_mod( 'thegoodplasticcompany_og_image', get_template_directory_uri() . '/assets/images/og-default.jpg' );
        echo '
<meta property="og:title" content="' . ( is_front_page() ? $s_name : trim( wp_title('', false) ) ) . '"/>
<meta property="og:site_name" content="' . $s_name . ' - ' . $s_desc . '"/>
<meta property="og:url" content="' . home_url($wp->request) . '"/>
<meta property="og:locale" content="' . get_locale() . '"/>';
        if( is_singular() && !is_front_page() ) {
            echo '
<meta property="og:type" content="article"/>';
            if(!has_post_thumbnail()) {
                echo '
<meta property="og:image" content="' . $default_thumb . '"/>';
            } else {
                $thumbnail_src = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' );
                echo '
<meta property="og:image" content="' . esc_attr( $thumbnail_src[0] ) . '"/>';
            }
        } else {
            echo '
<meta property="og:type" content="website"/>
<meta property="og:image" content="' . $default_thumb . '"/>';
        }
    }
    add_action( 'wp_head', 'thegoodplasticcompany_wp_head', 1 );
    
    /**
     * Get products
     */
    function thegoodplasticcompany_get_products($bespoke = false) {
        $args = $product_loop_args = array(
                            'post_type' 	=> 'product',
                            'post_status' 	=> 'publish',
                            'nopaging' 		=> true,
                            'posts_per_page' => -1,
                            'meta_query' 	=> array(
                                                    array(
                                                        'key' => 'out_of_production',
                                                        'value' => '1',
                                                        'compare' => $bespoke ? '===' : '!=',
                                                    )
                                                )
                        );
        return new WP_Query($args);
    }
    
    /**
     * Admin menu
     */
    function thegoodplasticcompany_admin_menu_customize() {
        //remove_menu_page( 'wpcf7' );
        remove_menu_page( 'edit.php?post_type=acf-field-group' );

        //add_options_page( __('Contact forms', 'thegoodplasticcompany'), __('Contact forms', 'thegoodplasticcompany'), 'manage_options', 'wpcf7' );
    }
    add_action( 'admin_menu', 'thegoodplasticcompany_admin_menu_customize' );