<?php
    /**
     * Custom Post Types class
     */
    if ( !class_exists( 'Custom Post Types' ) ):
        class Custom_Post_Types {
            protected $columns = array();
            
            public function __construct() {}
            
            public function register($post_types_array) {
                foreach( $post_types_array as $post_type => $args ) {
                    register_post_type( $post_type, $args);
                }
            }
            public function register_taxonomies($taxonomies_array) {
                foreach( $taxonomies_array as $post_type => $taxonomies ) {
                    foreach( $taxonomies as $taxonomy => $args ) {
                        register_taxonomy( $taxonomy, preg_split('/,\s?/',$post_type), $args);
                    }
                }
            }
            
            public function manage_columns( $columns ) {
                // remember and unset the 'date' column
                $date = $columns['date'];
                unset( $columns['date'] );

                // add our new columns as new array elements
                foreach( $this->columns as $column => $values ) {
                    if( isset($values['column_title']) ) {
                        $columns[$column] = $values['column_title'];
                    }
                }
                
                // set the 'date' column again and move it to the end
                $columns['date'] = $date;

                return $columns;
            }
            public function set_columns_order( $defaults ) {
                $i              = 0;
                $columns        = isset($defaults['cb']) ? array( 'cb' => $defaults['cb'] ) : array();
                $custom_keys    = array_keys($this->columns);
                for($i=0; $i<count($custom_keys); $i++) {
                    $key = $custom_keys[$i];
                    $columns[$key] = $defaults[$key];
                }
                
                return array_merge($columns, $defaults);
            }
            public function set_sortable_columns( $columns ) {
                foreach( $this->columns as $column => $values ) {
                    if ( isset( $values['column_orderby'] ) || $column == 'title' ) {
                        $columns[$column] = $column;
                    }
                }
                return $columns;
            }
            public function populate_custom_columns( $column, $post_id ) {
                foreach( $this->columns as $col => $values ) {
                    if ( $column === $col ) {
                        if ( preg_match( '/^(featured[-_]image)/' , $col) ) {
                    		echo wp_get_attachment_image( get_post_meta($post_id, ( isset($values['column_meta_key']) ? $values['column_meta_key'] : '_thumbnail_id' ), true), ( isset($values['column_image_size']) ? $values['column_image_size'] : 'thumbnail' ) ); 
                    	} else {
                            echo get_post_meta($post_id, $values['column_meta_key'], true);
                        }
                    }    
                }
            }
            public function sort_custom_column_query( $query ) {
                $orderby = $query->get( 'orderby' );
                foreach( $this->columns as $column => $values ) {
                    if ( isset( $values['column_orderby'] ) && $values['column_orderby'] === 'meta_value' && $column == $orderby ) {
                        if( isset( $values['column_meta_type'] ) ) $query->set( 'meta_type', $values['column_meta_type'] );
                        $query->set( 'meta_key', $values['column_meta_key'] );
                        $query->set( 'orderby', $values['column_orderby'] );
                    }
                }
            }
            
            public function sortable_columns($columns_array) {
                global $pagenow;
                
                foreach( $columns_array as $post_types => $columns ) {
                    $post_type_array = preg_split('/,\s?/',$post_types);
                    foreach( $post_type_array as $post_type ) {
                        if ( is_admin() && 'edit.php' == $pagenow && ( isset( $_GET['post_type'] ) && $post_type == $_GET['post_type'] ) ) {
                            
                            // set colunms array
                            $this->columns = $columns;

                            // manage colunms
                            add_filter( 'manage_' . $post_type . '_posts_columns', array( $this, 'manage_columns' ) );

                            // populate column cells
                            add_action( 'manage_' . $post_type . '_posts_custom_column', array( $this, 'populate_custom_columns' ), 10, 2 );
                            
                            // set columns order
                            add_filter('manage_edit-' . $post_type . '_columns', array( $this, 'set_columns_order' ) );
                            
                            // make columns sortable
                            add_filter( 'manage_edit-' . $post_type . '_sortable_columns', array( $this, 'set_sortable_columns' ) );

                        }
                    }
                }
                
                // set query to sort
                add_action( 'pre_get_posts', array( $this, 'sort_custom_column_query' ) );
            }
        }
    endif;