<?php
    /**
     * News feed block template
     *
     * @param   array $block The block settings and attributes.
     * @param   string $content The block inner HTML (empty).
     * @param   bool $is_preview True during AJAX preview.
     * @param   (int|string) $post_id The post ID this block is saved to.
     *
     */

    // Create id attribute allowing for custom "anchor" value.
    $id = 'content-news-feed-' . $block['id'];
    if( !empty($block['anchor']) ) {
        $id = $block['anchor'];
    }

    // Create class attribute allowing for custom "className" and "align" values.
    $className = 'content-news-feed';
    if( !empty($block['className']) ) {
        $className .= ' ' . $block['className'];
    }
?>
<div class="<?php echo esc_attr($className); ?>" id="<?php echo esc_attr($id); ?>">
  <div class="content-section-tagline mt-1 mb-2">
    <div class="row">
      <div class="col-12 col-lg-11 offset-lg-1">
        <?php
        echo '
        <h5>' . get_field('title') . '</h5>';
        if( $is_preview ) {
            echo '
        <hr/>';
        }?>
        
      </div>
    </div>
    <div class="content-section-tagline-mask border-bottom"></div>
  </div>
  <?php
  
  $order_by   = get_field('news_order_by');
  $news_count = get_field('news_count');
  $sticky     = get_option('sticky_posts');
  
  /* Query the sticky posts */
  $sq_args = array(
      'post__in'          => $sticky,
      'post_type'         => 'post',
      'post_status'       => 'publish',
      'posts_per_page'    => $news_count,
      'orderby'           => $order_by == 'random' ? 'rand' : 'post_date',
      'order'             => $order_by == 'random' ? 'ASC' : strtoupper($order_by)
  );
  $sq_loop = new WP_Query($sq_args);
  
  /* Sticky posts loop */
  while ( $sq_loop->have_posts() ) {
  	$sq_loop->the_post();
  
  	get_template_part( 'template-parts/content', 'post' );
      echo '
  <div class="content-section-tagline mb-2">
    <div class="content-section-tagline-mask border-bottom"></div>
  </div>';
  }
  
  /* Count the number of post returned by this query */
  $sq_count = $sq_loop->post_count;
  
  /* Check to see if any non-sticky posts need to be output */
  if($sq_count < $news_count) {
      $news_count_new = $news_count - $sq_count;
      
      /* Get projects with empty content */
      global $wpdb;
      $exclude_posts = $wpdb->get_results(
          $wpdb->prepare(
              "
                  SELECT post.ID
                  FROM {$wpdb->posts} AS post
                  WHERE post.post_type = '%s'
                  AND TRIM(IFNULL(post.post_content,'')) = ''
              ", 'project'
          ), ARRAY_A
      );
      $excluded = array_map('current',$exclude_posts);
      
      $loop_args = array(
                          'post__not_in'   => array_merge($excluded, $sticky),
                          'post_type'      => array('post','project'),
                          'post_status'    => 'publish',
                          'posts_per_page' => $news_count_new,
                          'orderby'        => $order_by == 'random' ? 'rand' : 'post_date',
                          'order'          => $order_by == 'random' ? 'ASC' : strtoupper($order_by)
                      );
      $loop = new WP_Query( $loop_args );
      
      /* Posts loop */
      while ( $loop->have_posts() ) {
      	$loop->the_post();
  
      	get_template_part( 'template-parts/content', 'post' );
          echo '
  <div class="content-section-tagline mb-2">
    <div class="content-section-tagline-mask border-bottom"></div>
  </div>';
      }
  }?>
  
</div>