<?php
    /**
     * Text rotator block template
     *
     * @param   array $block The block settings and attributes.
     * @param   string $content The block inner HTML (empty).
     * @param   bool $is_preview True during AJAX preview.
     * @param   (int|string) $post_id The post ID this block is saved to.
     *
     */

    // Create id attribute allowing for custom "anchor" value.
    $id = 'text-rotator-' . $block['id'];
    if( !empty($block['anchor']) ) {
        $id = $block['anchor'];
    }

    // Create class attribute allowing for custom "className" and "align" values.
    $className = 'content-text-rotator text-nowrap my-1 mt-lg-0 mb-lg-1';
    if( !empty($block['className']) ) {
        $className .= ' ' . $block['className'];
    }

    // Load values and assign defaults.
    $prefix     = get_field('prefix');
    $suffix     = get_field('suffix');
    $words_arr  = get_field('rotating') ?: array('word' => '...');
    $words      = array();
    $animation  = get_field('animation') ?: 'flipCubeUp';
    $speed      = get_field('speed') ?: 3000;
    foreach ($words_arr as $word_arr) {
        $words[] = $word_arr['word'];
    }
    ?>
<div class="<?php echo esc_attr($className); ?>" id="<?php echo esc_attr($id); ?>">
  <h3 class="text-uppercase"><span class="content-text-rotator-static"><?php echo $prefix; ?></span><span class="content-text-rotator-dynamic text-left" data-rotator-animation="<?php echo esc_attr($animation); ?>" data-rotator-speed="<?php echo esc_attr($speed); ?>" data-rotator-strings="<?php echo implode('|', $words); ?>"><?php echo reset($words); ?></span><span class="content-text-rotator-static"><?php echo $suffix; ?></span></h3>
</div>
<?php

if($is_preview) {
    echo '
<script type="text/javascript" src="' . get_stylesheet_directory_uri() . '/assets/scripts/editor/script-block-text-rotator.js' . '"></script>';
}
    ?>
